==> oasis_0.4.5.orig.tar.gz: oasis-0.4.5/src/cli/SetupDev.ml <==
(******************************************************************************)
(* OASIS: architecture for building OCaml libraries and applications          *)
(*                                                                            *)
(* Copyright (C) 2011-2013, Sylvain Le Gall                                   *)
(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
(*                                                                            *)
(* This library is free software; you can redistribute it and/or modify it    *)
(* under the terms of the GNU Lesser General Public License as published by   *)
(* the Free Software Foundation; either version 2.1 of the License, or (at    *)
(* your option) any later version, with the OCaml static compilation          *)
(* exception.                                                                 *)
(*                                                                            *)
(* This library is distributed in the hope that it will be useful, but        *)
(* WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *)
(* or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more         *)
(* details.                                                                   *)
(*                                                                            *)
(* You should have received a copy of the GNU Lesser General Public License   *)
(* along with this library; if not, write to the Free Software Foundation,    *)
(* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
(******************************************************************************)


(** Like Setup but in development mode (deprecated).
    @author Sylvain Le Gall
  *)


open CLISubCommand
open OASISGettext

let () =
  CLISubCommand.register "setup-dev"
    ~deprecated:true
    (ns_ "Deprecated.")
    CLIData.setup_dev_mkd
    (CLICommon.define_oasis_fn
       (CLISubCommand.make_run
          (fun () ->
             (["-real-oasis", Arg.Unit ignore, s_ " Deprecated";
               "-run", Arg.Rest ignore, s_ " Deprecated.";
               "-only-setup", Arg.Set (ref false), s_ " Deprecated."],
              CLISubCommand.default_anon),
             ignore)
          (fun ~ctxt () oasis_fn ->
             failwith
               (s_ "The SetupDev subcommand is deprecated, use Setup"))))

==> oasis_0.4.10.orig.tar.gz: oasis-0.4.10/src/cli/SetupDev.ml <==
(******************************************************************************)
(* OASIS: architecture for building OCaml libraries and applications          *)
(*                                                                            *)
(* Copyright (C) 2011-2016, Sylvain Le Gall                                   *)
(* Copyright (C) 2008-2011, OCamlCore SARL                                    *)
(*                                                                            *)
(* This library is free software; you can redistribute it and/or modify it    *)
(* under the terms of the GNU Lesser General Public License as published by   *)
(* the Free Software Foundation; either version 2.1 of the License, or (at    *)
(* your option) any later version, with the OCaml static compilation          *)
(* exception.                                                                 *)
(*                                                                            *)
(* This library is distributed in the hope that it will be useful, but        *)
(* WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY *)
(* or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more         *)
(* details.                                                                   *)
(*                                                                            *)
(* You should have received a copy of the GNU Lesser General Public License   *)
(* along with this library; if not, write to the Free Software Foundation,    *)
(* Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA              *)
(******************************************************************************)


(** Like Setup but in development mode (deprecated).
    @author Sylvain Le Gall
*)


open OASISGettext

let () =
  CLISubCommand.register "setup-dev"
    ~deprecated:true
    ~synopsis:(ns_ "Deprecated.")
    ~help:CLIData.setup_dev_mkd
    (CLICommon.define_oasis_fn
       (CLISubCommand.make_run
          (fun () ->
             (["-real-oasis", Arg.Unit ignore, s_ " Deprecated";
               "-run", Arg.Rest ignore, s_ " Deprecated.";
               "-only-setup", Arg.Set (ref false), s_ " Deprecated."],
              CLISubCommand.default_anon),
             ignore)
          (fun ~ctxt () oasis_fn ->
             failwith
               (s_ "The SetupDev subcommand is deprecated, use Setup"))))
